@@ -31,9 +31,12 @@ if model.get_user(user_id=user_id, check_active=False):
         "user_id": user_id,
         "user_name": username,
         "password": User.encode_password(password, crypt_util.get_random_string()),
+        "has_access": True,
         "is_active": True,
         "is_verified": True,
     }
     model.update_user_info(update)
 else:
-    model.add_user(username, '', '', '', password, '', user_id=user_id, is_verified=True)
+    model.add_user(
+        username, '', '', '', password, '', user_id=user_id, is_verified=True, has_access=True
+    )
