@@ -17,7 +17,7 @@ for path in sys.argv[1:]:
         bundle_type = 'program'
         tags = info['task']
     else:
-        raise 'Weird info: %s' % info
+        raise ValueError('Weird info: %s' % info)
 
     name = info['name'].replace(' ', '_')
     cmd = "cl upload %s `/bin/ls -d %s/*` --name %s --tags mlcomp %s --description \"%s\"" % (
